==> 1.3.0.tar.gz: manager/pages/friends.php <==
<?php
    if($_SERVER['REQUEST_METHOD'] == 'POST')
    {
        if(isset($_POST['remove'])) {
            include 'app/FormValidator.php';
            $validator = new FormValidator(array(
                'uuid' => array('required' => true, 'regex' => '/^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$/')
            ));

            if($validator->isValid($_POST)) {
                $statementMembership = $RUNTIME['PDO']->prepare("DELETE FROM Friends WHERE Friend = ? AND PrincipalID = ?");
                $statementMembership->execute(array($_REQUEST['uuid'], $_SESSION['UUID']));
        
                $statementMembership = $RUNTIME['PDO']->prepare("DELETE FROM Friends WHERE PrincipalID = ? AND Friend = ?");
                $statementMembership->execute(array($_REQUEST['uuid'], $_SESSION['UUID']));
            }
        }

        header('Location: index.php?page=friends');
        die();
    }

    $HTML->setHTMLTitle("Deine Freunde");
	$HTML->importSeitenInhalt("online-anzeige.html");

    $table = '<table class="table"><thead><tr><th scope="col">Name</th><th scope="col">Optionen</th></thead><tbody>%%ENTRY%%</tbody></table>';
    
    $statement = $RUNTIME['PDO']->prepare("SELECT PrincipalID,Friend FROM Friends WHERE PrincipalID = ? ORDER BY Friend ASC");
    $statement->execute([$_SESSION['UUID']]); 

    while($row = $statement->fetch()) 
    {
        $PrincipalID = explode(";", $row['PrincipalID'])[0];
        $FriendData = explode(";", $row['Friend']);
        $Friend = $FriendData[0];

        include 'app/OpenSim.php';
        $opensim = new OpenSim();

        $name = trim($opensim->getUserName($Friend));
        if(count($FriendData) > 1) {
            $FriendData[1] = str_replace("http://", "", $FriendData[1]);
            $FriendData[1] = str_replace("https://", "", $FriendData[1]);
            $FriendData[1] = str_replace("/", "", $FriendData[1]);
            $name = $name.' @ '.strtolower($FriendData[1]);
        }

        $entry = '<tr><td>'.htmlspecialchars($name).'</td><td><form action="index.php?page=friends" method="post">%%CSRF%%<input type="hidden" name="uuid" value="'.htmlspecialchars($row['Friend']).'"><button type="submit" name="remove" class="btn btn-danger btn-sm">LÖSCHEN</button></form></td></tr>';

        $table = str_replace("%%ENTRY%%", $entry."%%ENTRY%%", $table);
    }

    $table = str_replace("%%ENTRY%%", "", $table);
    $HTML->ReplaceSeitenInhalt("%%ONLINE-LIST%%", $table);

    $HTML->build();
    echo $HTML->ausgabe();
?>

==> 1.4.0.tar.gz: manager/pages/friends.php <==
<?php
    if ($_SERVER['REQUEST_METHOD'] == 'POST') {
        if (isset($_POST['remove'])) {
            include_once 'app/FormValidator.php';
            $validator = new FormValidator(array(
                'uuid' => array('required' => true, 'regex' => '/^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$/')
            ));

            if ($validator->isValid($_POST)) {
                $statementMembership = $RUNTIME['PDO']->prepare("DELETE FROM Friends WHERE Friend = ? AND PrincipalID = ?");
                $statementMembership->execute(array($_REQUEST['uuid'], $_SESSION['UUID']));
        
                $statementMembership = $RUNTIME['PDO']->prepare("DELETE FROM Friends WHERE PrincipalID = ? AND Friend = ?");
                $statementMembership->execute(array($_REQUEST['uuid'], $_SESSION['UUID']));
            }
        }

        header('Location: index.php?page=friends');
        die();
    }

    $HTML->setHTMLTitle("Deine Freunde");
    $HTML->importSeitenInhalt("online-anzeige.html");

    $table = '<table class="table"><thead><tr><th scope="col">Name</th><th scope="col">Optionen</th></thead><tbody>%%ENTRY%%</tbody></table>';
    
    $statement = $RUNTIME['PDO']->prepare("SELECT PrincipalID,Friend FROM Friends WHERE PrincipalID = ? ORDER BY Friend ASC");
    $statement->execute([$_SESSION['UUID']]);

    include_once 'app/OpenSim.php';
    $opensim = new OpenSim();

    while ($row = $statement->fetch()) {
        $PrincipalID = explode(";", $row['PrincipalID'])[0];
        $FriendData = explode(";", $row['Friend']);
        $Friend = $FriendData[0];

        $name = trim($opensim->getUserName($Friend));
        if (count($FriendData) > 1) {
            $FriendData[1] = str_replace("http://", "", $FriendData[1]);
            $FriendData[1] = str_replace("https://", "", $FriendData[1]);
            $FriendData[1] = str_replace("/", "", $FriendData[1]);
            $name = $name.' @ '.strtolower($FriendData[1]);
        }

        $entry = '<tr><td>'.htmlspecialchars($name).'</td><td><form action="index.php?page=friends" method="post">%%CSRF%%<input type="hidden" name="uuid" value="'.htmlspecialchars($row['Friend']).'"><button type="submit" name="remove" class="btn btn-danger btn-sm">LÖSCHEN</button></form></td></tr>';

        $table = str_replace("%%ENTRY%%", $entry."%%ENTRY%%", $table);
    }

    $table = str_replace("%%ENTRY%%", "", $table);
    $HTML->ReplaceSeitenInhalt("%%ONLINE-LIST%%", $table);

    $HTML->build();
    echo $HTML->ausgabe();
